// ============================================================================
// Project:	A Tiny DBMS (Exercise for Course "DBMS-Implementation")
// Filename:	btype.h
// Purpose:	Enumeration type for different types/kinds of blocks
// Last Change:	20.02.2012
// Language:	C++
// EMail:	brass@informatik.uni-halle.de
// WWW:		http://www.informatik.uni-halle.de/~brass/
// Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
// Copyright:	(c) 2011-2012 by Stefan Brass
// License:	See file "LICENSE" for copying conditions.
// Note:	There is no warranty at all - this code may contain bugs.
// ============================================================================


//=============================================================================
// Include File Frame:
//=============================================================================

#ifndef	BTYPE_INCLUDED
#define BTYPE_INCLUDED

//=============================================================================
// Used Types and Macros:
//=============================================================================

#ifndef VER_INCLUDED
#include "ver.h"
#endif

#ifndef STR_INCLUDED
#include "str.h"
#endif

#ifndef CHECK_INCLUDED
#include "check.h"
#endif


//=============================================================================
// Exported Types:
//=============================================================================

//-----------------------------------------------------------------------------
// btype_t: Enumeration type for different types/kinds of blocks.
//-----------------------------------------------------------------------------

typedef enum {
	BTYPE_INVALID,	/* Block not yet initialized */
	BTYPE_EMPTY,	/* E.g. free buffer or not assigned to segment */
	BTYPE_FILE_HEADER, /* File Header Block */
	BTYPE_REL_DATA	/* Data Block for a Relation */
} btype_t;


//=============================================================================
// Exported Functions:
//=============================================================================

//-----------------------------------------------------------------------------
// btype_valid: Function to check whether btype value is legal, NULL means ok.
//-----------------------------------------------------------------------------

inline str_t btype_valid(btype_t btype)
{
	switch(btype) {
	case BTYPE_INVALID:
		return "Block type is BTYPE_INVALID";
	case BTYPE_EMPTY:
	case BTYPE_FILE_HEADER:
	case BTYPE_REL_DATA:
		return 0;
	default:
		return "Unknown block type";
	}
}

//=============================================================================
// End of Include File:
//=============================================================================

#endif

